================
Getting Started
================

.. include:: ../README.rst
   :start-after: start-in-sphinx-getting-started-overview
   :end-before: end-in-sphinx-getting-started-overview

Quickstart
================

.. include:: ../README.rst
   :start-after: start-in-sphinx-getting-started-quickstart
   :end-before: end-in-sphinx-getting-started-quickstart
